==> haskell-rere-0.2.0.1-23-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-JGGigxzkR0GFF2wlc7KQsc
key:                  rere-0.2.0.1-JGGigxzkR0GFF2wlc7KQsc
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  6909871389389c502b76e7bc1798f548
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-JGGigxzkR0GFF2wlc7KQsc
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    containers-0.6.5.1 fin-0.3-JQq7S1k4qmdFTezinMbV6O parsec-3.1.15.0
    transformers-0.5.6.2 vec-0.5-1fBOgb9FFA06iJdGGp8di6

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rere-0.2.0.1-33-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-5L5SWvn2jxo9QLJyQL0axR
key:                  rere-0.2.0.1-5L5SWvn2jxo9QLJyQL0axR
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  b29c498f792d7ff94bd283f476914ef3
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-5L5SWvn2jxo9QLJyQL0axR
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    containers-0.6.5.1 fin-0.3-5vHQ7TQ9dtFFudMxULyIqz parsec-3.1.15.0
    transformers-0.5.6.2 vec-0.5-LlU7xO2BBPpGMylGNdOTKJ

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
